@@ -4,8 +4,7 @@
 #include <vector>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_multiplicable.hpp>
-#include <stan/math/matrix/validate_square.hpp>
+#include <stan/math/error_handling/matrix/check_multiplicable.hpp>
 #include <stan/agrad/fwd/fvar.hpp>
 #include <stan/agrad/fwd/matrix/typedefs.hpp>
 #include <stan/agrad/fwd/matrix/inverse.hpp>
@@ -15,6 +14,7 @@
 #include <stan/math/matrix/inverse.hpp>
 #include <stan/agrad/fwd/matrix/inverse.hpp>
 #include <stan/math/matrix/mdivide_left.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
   namespace agrad {
@@ -27,8 +27,9 @@ namespace stan {
       
       using stan::math::multiply;      
       using stan::math::mdivide_left;
-      stan::math::validate_square(A,"mdivide_left");
-      stan::math::validate_multiplicable(A,b,"mdivide_left");
+      stan::math::check_square("mdivide_left(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R1,C2> inv_A_mult_b(A.rows(),b.cols());
       Eigen::Matrix<T,R1,C2> inv_A_mult_deriv_b(A.rows(),b.cols());
@@ -70,8 +71,9 @@ namespace stan {
       
       using stan::math::multiply;      
       using stan::math::mdivide_left;
-      stan::math::validate_square(A,"mdivide_left");
-      stan::math::validate_multiplicable(A,b,"mdivide_left");
+      stan::math::check_square("mdivide_left(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R2,C2> val_b(b.rows(),b.cols()); 
       Eigen::Matrix<T,R2,C2> deriv_b(b.rows(),b.cols()); 
@@ -95,8 +97,9 @@ namespace stan {
       
       using stan::math::multiply;      
       using stan::math::mdivide_left;
-      stan::math::validate_square(A,"mdivide_left");
-      stan::math::validate_multiplicable(A,b,"mdivide_left");
+      stan::math::check_square("mdivide_left(%1%)",A,"A",(double*)0);
+      stan::math::check_multiplicable("mdivide_left(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R1,C2> 
         inv_A_mult_b(A.rows(),b.cols());
