@@ -4,12 +4,18 @@
 #include <vector>
 #include <stan/math/matrix/Eigen.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_multiplicable.hpp>
-#include <stan/math/matrix/validate_square.hpp>
+#include <stan/math/matrix/mdivide_right.hpp>
+#include <stan/math/error_handling/matrix/check_multiplicable.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 #include <stan/agrad/fwd/fvar.hpp>
 #include <stan/agrad/fwd/matrix/typedefs.hpp>
 #include <stan/agrad/fwd/matrix/inverse.hpp>
 #include <stan/agrad/fwd/matrix/multiply.hpp>
+#include <stan/math/matrix/multiply.hpp>
+#include <stan/agrad/fwd/matrix/to_fvar.hpp>
+#include <stan/math/matrix/inverse.hpp>
+#include <stan/agrad/fwd/matrix/inverse.hpp>
+#include <stan/math/matrix/mdivide_right.hpp>
 
 namespace stan {
   namespace agrad {
@@ -22,8 +28,9 @@ namespace stan {
       
       using stan::math::multiply;      
       using stan::math::mdivide_right;
-      stan::math::validate_square(b,"mdivide_right");
-      stan::math::validate_multiplicable(A,b,"mdivide_right");
+      stan::math::check_square("mdivide_right(%1%)",b,"b",(double*)0);
+      stan::math::check_multiplicable("mdivide_right(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R1,C2> A_mult_inv_b(A.rows(),b.cols());
       Eigen::Matrix<T,R1,C2> deriv_A_mult_inv_b(A.rows(),b.cols());
@@ -65,8 +72,9 @@ namespace stan {
       
       using stan::math::multiply;      
       using stan::math::mdivide_right;
-      stan::math::validate_square(b,"mdivide_right");
-      stan::math::validate_multiplicable(A,b,"mdivide_right");
+      stan::math::check_square("mdivide_right(%1%)",b,"b",(double*)0);
+      stan::math::check_multiplicable("mdivide_right(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R2,C2> deriv_b_mult_inv_b(b.rows(),b.cols());
       Eigen::Matrix<T,R1,C1> val_A(A.rows(),A.cols()); 
@@ -91,9 +99,9 @@ namespace stan {
       
       using stan::math::multiply;      
       using stan::math::mdivide_right;
-      stan::math::validate_square(b,"mdivide_right");
-      stan::math::validate_multiplicable(A,b,"mdivide_right");
-
+      stan::math::check_square("mdivide_right(%1%)",b,"b",(double*)0);
+      stan::math::check_multiplicable("mdivide_right(%1%)",A,"A",
+                                      b,"b",(double*)0);
       Eigen::Matrix<T,R1,C2> 
         A_mult_inv_b(A.rows(),b.cols());
       Eigen::Matrix<T,R2,C2> deriv_b_mult_inv_b(b.rows(),b.cols());
