@@ -3,9 +3,10 @@
 
 #include <vector>
 #include <stan/math/matrix/Eigen.hpp>
+#include <stan/math/matrix/mdivide_right.hpp>
 #include <stan/math/matrix/typedefs.hpp>
-#include <stan/math/matrix/validate_square.hpp>
-#include <stan/math/matrix/validate_multiplicable.hpp>
+#include <stan/math/error_handling/matrix/check_multiplicable.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 #include <stan/agrad/fwd/matrix/typedefs.hpp>
 #include <stan/agrad/fwd/matrix/to_fvar.hpp>
 #include <stan/agrad/fwd/matrix/multiply.hpp>
@@ -22,8 +23,9 @@ namespace stan {
                           const Eigen::Matrix<fvar<T>, R2, C2>& b) {
       using stan::math::multiply;      
       using stan::math::mdivide_right;
-      stan::math::validate_square(b,"mdivide_right");
-      stan::math::validate_multiplicable(A,b,"mdivide_right");
+      stan::math::check_square("mdivide_right_tri_low(%1%)",b,"b",(double*)0);
+      stan::math::check_multiplicable("mdivide_right_tri_low(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R1,C2> A_mult_inv_b(A.rows(),b.cols());
       Eigen::Matrix<T,R1,C2> deriv_A_mult_inv_b(A.rows(),b.cols());
@@ -67,8 +69,9 @@ namespace stan {
       
       using stan::math::multiply;      
       using stan::math::mdivide_right;
-      stan::math::validate_square(b,"mdivide_right");
-      stan::math::validate_multiplicable(A,b,"mdivide_right");
+      stan::math::check_square("mdivide_right_tri_low(%1%)",b,"b",(double*)0);
+      stan::math::check_multiplicable("mdivide_right_tri_low(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R2,C2> deriv_b_mult_inv_b(b.rows(),b.cols());
       Eigen::Matrix<T,R1,C1> val_A(A.rows(),A.cols()); 
@@ -101,8 +104,9 @@ namespace stan {
       
       using stan::math::multiply;      
       using stan::math::mdivide_right;
-      stan::math::validate_square(b,"mdivide_right");
-      stan::math::validate_multiplicable(A,b,"mdivide_right");
+      stan::math::check_square("mdivide_right_tri_low(%1%)",b,"b",(double*)0);
+      stan::math::check_multiplicable("mdivide_right_tri_low(%1%)",A,"A",
+                                      b,"b",(double*)0);
 
       Eigen::Matrix<T,R1,C2> 
         A_mult_inv_b(A.rows(),b.cols());
