@@ -104,6 +104,7 @@ namespace stan {
     class function_signatures {
     public:
       static function_signatures& instance();
+      static void reset_sigs();
       void set_user_defined(const std::pair<std::string,function_signature_t>&
                             name_sig);
       bool is_user_defined(const std::pair<std::string,function_signature_t>&
@@ -518,6 +519,14 @@ namespace stan {
                                std::vector<expression> const& dims);
     };
 
+    struct cholesky_corr_var_decl : public base_var_decl {
+      expression K_;
+      cholesky_corr_var_decl();
+      cholesky_corr_var_decl(const expression& K,
+                             const std::string& name,
+                             const std::vector<expression>& dims);
+    };
+
     struct cov_matrix_var_decl : public base_var_decl {
       expression K_;
       cov_matrix_var_decl();
@@ -548,6 +557,7 @@ namespace stan {
       std::string operator()(const ordered_var_decl& x) const;
       std::string operator()(const positive_ordered_var_decl& x) const;
       std::string operator()(const cholesky_factor_var_decl& x) const;
+      std::string operator()(const cholesky_corr_var_decl& x) const;
       std::string operator()(const cov_matrix_var_decl& x) const;
       std::string operator()(const corr_matrix_var_decl& x) const;
     };
@@ -567,6 +577,7 @@ namespace stan {
                              boost::recursive_wrapper<ordered_var_decl>,
                              boost::recursive_wrapper<positive_ordered_var_decl>,
                              boost::recursive_wrapper<cholesky_factor_var_decl>,
+                             boost::recursive_wrapper<cholesky_corr_var_decl>,
                              boost::recursive_wrapper<cov_matrix_var_decl>,
                              boost::recursive_wrapper<corr_matrix_var_decl> >
       var_decl_t;
@@ -589,6 +600,7 @@ namespace stan {
       var_decl(const ordered_var_decl& decl);
       var_decl(const positive_ordered_var_decl& decl);
       var_decl(const cholesky_factor_var_decl& decl);
+      var_decl(const cholesky_corr_var_decl& decl);
       var_decl(const cov_matrix_var_decl& decl);
       var_decl(const corr_matrix_var_decl& decl);
 
