@@ -43,7 +43,6 @@
 #include <stan/gm/ast.hpp>
 #include <stan/gm/grammars/whitespace_grammar.hpp>
 #include <stan/gm/grammars/expression_grammar.hpp>
-#include <stan/gm/grammars/var_decls_grammar.hpp>
 #include <stan/gm/grammars/statement_grammar.hpp>
 #include <stan/gm/grammars/statement_2_grammar.hpp>
 #include <stan/gm/grammars/common_adaptors_def.hpp>
@@ -53,21 +52,22 @@ namespace stan {
 
   namespace gm {
 
-
-
     struct add_conditional_condition {
-      template <typename T1, typename T2, typename T3>
-      struct result { typedef bool type; };
-      bool operator()(conditional_statement& cs,
+      template <typename T1, typename T2, typename T3, typename T4>
+      struct result { typedef void type; };
+      void operator()(conditional_statement& cs,
                       const expression& e,
+                      bool& pass,
                       std::stringstream& error_msgs) const {
         if (!e.expression_type().is_primitive()) {
           error_msgs << "conditions in if-else statement must be primitive int or real;"
                      << " found type=" << e.expression_type() << std::endl;
-          return false;
+          pass = false;
+          return;
         }
         cs.conditions_.push_back(e);
-        return true;
+        pass = true;
+        return;
       }               
     };
     boost::phoenix::function<add_conditional_condition> add_conditional_condition_f;
@@ -102,13 +102,14 @@ namespace stan {
 
       using boost::spirit::qi::labels::_r1;
       using boost::spirit::qi::labels::_r2;
+      using boost::spirit::qi::labels::_r3;
 
       // _r1 true if sample_r allowed (inherited)
       // _r2 source of variables allowed for assignments
       // set to true if sample_r are allowed
       statement_2_r.name("statement");
       statement_2_r
-        %= conditional_statement_r(_r1,_r2)
+        %= conditional_statement_r(_r1,_r2,_r3)
         ;
 
       
@@ -117,23 +118,23 @@ namespace stan {
         = lit("if")
         > lit('(')
         > expression_g(_r2)
-          [_pass = add_conditional_condition_f(_val,_1,
-                                               boost::phoenix::ref(error_msgs_))]
+          [add_conditional_condition_f(_val,_1,_pass,
+                                       boost::phoenix::ref(error_msgs_))]
         > lit(')')
-        > statement_g(_r1,_r2)
-        [add_conditional_body_f(_val,_1)]
+        > statement_g(_r1,_r2,_r3)
+          [add_conditional_body_f(_val,_1)]
         > * (( lit("else")
                >> lit("if") )
              > lit('(')
              > expression_g(_r2)
-               [_pass = add_conditional_condition_f(_val,_1,
-                                                    boost::phoenix::ref(error_msgs_))]
+               [add_conditional_condition_f(_val,_1,_pass,
+                                            boost::phoenix::ref(error_msgs_))]
              > lit(')')
-             > statement_g(_r1,_r2)
+             > statement_g(_r1,_r2,_r3)
                [add_conditional_body_f(_val,_1)]
              )
         > - (lit("else") 
-             > statement_g(_r1,_r2)
+             > statement_g(_r1,_r2,_r3)
                [add_conditional_body_f(_val,_1)]
              )
         ;
