@@ -20,7 +20,7 @@ namespace stan {
     template <typename Iterator>
     struct statement_grammar 
       : boost::spirit::qi::grammar<Iterator,
-                                   statement(bool,var_origin),
+                                   statement(bool,var_origin,bool),
                                    whitespace_grammar<Iterator> > {
 
   
@@ -63,19 +63,19 @@ namespace stan {
 
 
       boost::spirit::qi::rule<Iterator, 
-                              increment_log_prob_statement(var_origin), 
+                              increment_log_prob_statement(bool,var_origin), 
                               whitespace_grammar<Iterator> > 
       increment_log_prob_statement_r;
 
       boost::spirit::qi::rule<Iterator, 
                               boost::spirit::qi::locals<std::string>, 
-                              for_statement(bool,var_origin), 
+                              for_statement(bool,var_origin,bool), 
                               whitespace_grammar<Iterator> > 
       for_statement_r;
 
 
       boost::spirit::qi::rule<Iterator, 
-                              while_statement(bool,var_origin), 
+                              while_statement(bool,var_origin,bool), 
                               whitespace_grammar<Iterator> > 
       while_statement_r;
 
@@ -86,6 +86,19 @@ namespace stan {
       print_statement_r;
 
 
+      boost::spirit::qi::rule<Iterator,
+                              return_statement(var_origin),
+                              whitespace_grammar<Iterator> >
+      return_statement_r;
+
+      boost::spirit::qi::rule<Iterator,
+                              return_statement(var_origin),
+                              whitespace_grammar<Iterator> >
+      void_return_statement_r;
+  
+
+
+
       boost::spirit::qi::rule<Iterator,
                               printable(var_origin),
                               whitespace_grammar<Iterator> >
@@ -128,13 +141,13 @@ namespace stan {
       sample_r;
 
       boost::spirit::qi::rule<Iterator,
-                              statement(bool,var_origin), 
+                              statement(bool,var_origin,bool), 
                               whitespace_grammar<Iterator> > 
       statement_r;
 
       boost::spirit::qi::rule<Iterator, 
                               boost::spirit::qi::locals<std::vector<var_decl> >,
-                              statements(bool,var_origin), 
+                              statements(bool,var_origin,bool), 
                               whitespace_grammar<Iterator> >
       statement_seq_r;
 
