@@ -13,22 +13,13 @@
 #include <vector>
 #include <stdexcept>
 
-#include <boost/spirit/include/qi.hpp>
-// FIXME: get rid of unused include
-#include <boost/spirit/include/phoenix_core.hpp>
-#include <boost/spirit/include/phoenix_function.hpp>
-#include <boost/spirit/include/phoenix_fusion.hpp>
-#include <boost/spirit/include/phoenix_object.hpp>
-#include <boost/spirit/include/phoenix_operator.hpp>
-#include <boost/spirit/include/phoenix_stl.hpp>
 
+#include <boost/spirit/include/qi.hpp>
 #include <boost/lexical_cast.hpp>
 #include <boost/fusion/include/adapt_struct.hpp>
 #include <boost/fusion/include/std_pair.hpp>
 #include <boost/config/warning_disable.hpp>
-#include <boost/spirit/include/qi.hpp>
 #include <boost/spirit/include/qi_numeric.hpp>
-#include <boost/spirit/include/classic_position_iterator.hpp>
 #include <boost/spirit/include/phoenix_core.hpp>
 #include <boost/spirit/include/phoenix_function.hpp>
 #include <boost/spirit/include/phoenix_fusion.hpp>
@@ -40,6 +31,9 @@
 #include <boost/variant/apply_visitor.hpp>
 #include <boost/variant/recursive_variant.hpp>
 
+#include <boost/spirit/include/version.hpp>
+#include <boost/spirit/include/support_line_pos_iterator.hpp>
+
 #include <stan/gm/ast.hpp>
 #include <stan/gm/grammars/whitespace_grammar.hpp>
 #include <stan/gm/grammars/expression_grammar.hpp>
@@ -64,6 +58,9 @@ BOOST_FUSION_ADAPT_STRUCT(stan::gm::for_statement,
                           (stan::gm::range, range_)
                           (stan::gm::statement, statement_) );
 
+BOOST_FUSION_ADAPT_STRUCT(stan::gm::return_statement,
+                          (stan::gm::expression, return_value_) );
+
 BOOST_FUSION_ADAPT_STRUCT(stan::gm::print_statement,
                           (std::vector<stan::gm::printable>, printables_) );
 
@@ -83,6 +80,44 @@ namespace stan {
 
   namespace gm {
 
+    struct validate_return_allowed {
+      template <typename T1, typename T2, typename T3>
+      struct result { typedef void type; };
+      void operator()(var_origin origin,
+                      bool& pass,
+                      std::ostream& error_msgs) const {
+        if (origin != function_argument_origin
+            && origin != function_argument_origin_lp
+            && origin != function_argument_origin_rng) {
+          error_msgs << "Returns only allowed from function bodies." << std::endl;
+          pass = false;
+          return;
+        }
+        pass = true;
+      }
+    };
+    boost::phoenix::function<validate_return_allowed> validate_return_allowed_f;
+
+    struct validate_void_return_allowed {
+      template <typename T1, typename T2, typename T3>
+      struct result { typedef void type; };
+      void operator()(var_origin origin,
+                      bool& pass,
+                      std::ostream& error_msgs) const {
+        if (origin != void_function_argument_origin
+            && origin != void_function_argument_origin_lp
+            && origin != void_function_argument_origin_rng) {
+          error_msgs << "Void returns only allowed from function bodies of void return type." 
+                     << std::endl;
+          pass = false;
+          return;
+        }
+        pass = true;
+      }
+    };
+    boost::phoenix::function<validate_void_return_allowed> validate_void_return_allowed_f;
+
+
     struct validate_assignment {
       template <typename T1, typename T2, typename T3, typename T4>
       struct result { typedef bool type; };
@@ -90,7 +125,7 @@ namespace stan {
       bool operator()(assignment& a,
                       const var_origin& origin_allowed,
                       variable_map& vm,
-                      std::stringstream& error_msgs) const {
+                      std::ostream& error_msgs) const {
 
         // validate existence
         std::string name = a.var_dims_.name_;
@@ -100,7 +135,7 @@ namespace stan {
                      << std::endl;
           return false;
         }
-        
+
         // validate origin
         var_origin lhs_origin = vm.get_origin(name);
         if (lhs_origin != local_origin
@@ -112,6 +147,21 @@ namespace stan {
           return false;
         }
 
+        // enforce constancy of function args
+        if (lhs_origin == function_argument_origin
+            || lhs_origin == function_argument_origin_lp
+            || lhs_origin == function_argument_origin_rng
+            || lhs_origin == void_function_argument_origin
+            || lhs_origin == void_function_argument_origin_lp
+            || lhs_origin == void_function_argument_origin_rng) {
+          error_msgs << "Illegal to assign to function argument variables."
+                     << std::endl
+                     << "Use local variables instead.";
+          return false;
+        }
+            
+        
+
         // validate types
         a.var_type_ = vm.get(name);
         size_t lhs_var_num_dims = a.var_type_.dims_.size();
@@ -190,14 +240,15 @@ namespace stan {
         if (has_non_param_var(s.expr_,var_map)) {
           // FIXME:  really want to get line numbers in here too
           error_msgs << "Warning (non-fatal):"
-                     << "     sampling statement (~) contains a transformed parameter or local variable."
-                     << std::endl
-                     << "     You must increment lp__ with the log absolute determinant"
-                     << " of the Jacobian of the transform."
-                     << std::endl
-                     << "     Sampling Statement left-hand-side expression:"
-                     << std::endl
-                     << "          ";
+             << " Left-hand side of sampling statement (~) contains a non-linear"
+             << " transform of a parameter or local variable."
+             << std::endl
+             << " You must call increment_log_prob() with the log absolute determinant"
+             << " of the Jacobian of the transform."
+             << std::endl
+             << "  Sampling Statement left-hand-side expression:"
+             << std::endl
+             << "    ";
           generate_expression(s.expr_,error_msgs);
           error_msgs << " ~ ";
           error_msgs << function_name << "(...)";
@@ -300,24 +351,29 @@ namespace stan {
       void operator()(bool& pass,
                       const stan::gm::expression& expr,
                       std::stringstream& error_msgs) const {
-        error_msgs << "Illegal statement beginning with expression parsed as"
-                   << std::endl << "  ";
-        generate_expression(expr.expr_,error_msgs);
-        error_msgs << std::endl
-           << "Not a legal assignment or sampling statement.  Note that"
-           << std::endl
-           << "  * Assignment statements only allow variables (with optional indexes) on the left;"
-           << std::endl
-           << "    if you see an outer function logical_lt (<) with negated (-) second argument,"
-           << std::endl
-           << "    it indicates an assignment statement A <- B with illegal left"
-           << std::endl
-           << "    side A parsed as expression (A < (-B))."
-           << std::endl
-           << "  * Sampling statements allow arbitrary value-denoting expressions on the left."
-           << std::endl
-           << std::endl << std::endl;
-        pass = false;
+        if (expr.expression_type() != VOID_T) {
+          error_msgs << "Illegal statement beginning with non-void expression parsed as"
+                     << std::endl << "  ";
+          generate_expression(expr.expr_,error_msgs);
+          error_msgs << std::endl
+                     << "Not a legal assignment, sampling, or function statement.  Note that"
+                     << std::endl
+                     << "  * Assignment statements only allow variables (with optional indexes) on the left;"
+                     << std::endl
+                     << "    if you see an outer function logical_lt (<) with negated (-) second argument,"
+                     << std::endl
+                     << "    it indicates an assignment statement A <- B with illegal left"
+                     << std::endl
+                     << "    side A parsed as expression (A < (-B))."
+                     << std::endl
+                     << "  * Sampling statements allow arbitrary value-denoting expressions on the left."
+                     << std::endl
+                     << "  * Functions used as statements must be declared to have void returns"
+                     << std::endl << std::endl;
+          pass = false;
+          return;
+        }
+        pass = true;
       }
     };
     boost::phoenix::function<expression_as_statement> expression_as_statement_f;
@@ -393,37 +449,68 @@ namespace stan {
     boost::phoenix::function<remove_loop_identifier> remove_loop_identifier_f;
 
     struct validate_int_expr2 {
-      template <typename T1, typename T2>
-      struct result { typedef bool type; };
+      template <typename T1, typename T2, typename T3>
+      struct result { typedef void type; };
 
-      bool operator()(const expression& expr,
+      void operator()(const expression& expr,
+                      bool& pass,
                       std::stringstream& error_msgs) const {
         if (!expr.expression_type().is_primitive_int()) {
           error_msgs << "expression denoting integer required; found type=" 
                      << expr.expression_type() << std::endl;
-          return false;
+          pass = false;
+          return;
         }
-        return true;
+        pass = true;
+        return;
       }
     };
     boost::phoenix::function<validate_int_expr2> validate_int_expr2_f;
 
     struct validate_allow_sample {
-      template <typename T1, typename T2>
-      struct result { typedef bool type; };
+      template <typename T1, typename T2, typename T3>
+      struct result { typedef void type; };
 
-      bool operator()(const bool& allow_sample,
+      void operator()(const bool& allow_sample,
+                      bool& pass,
                       std::stringstream& error_msgs) const {
         if (!allow_sample) {
-          error_msgs << "ERROR:  sampling only allowed in model."
+          error_msgs << "sampling only allowed in model."
                      << std::endl;
-          return false;
+          pass = false;
+          return;
         }
-        return true;
+        pass = true;
+        return;
       }
     };
     boost::phoenix::function<validate_allow_sample> validate_allow_sample_f;
 
+    // // REMOVE ME
+    // namespace stan { 
+    //   namespace gm {
+    //     void generate_statement(const statement& s,
+    //                             int indent,
+    //                             std::ostream& os,
+    //                             bool is_var, bool is_fun_return, bool include_sampling);
+    //   }
+    // }
+
+    struct validate_non_void_expression {
+      template <typename T1, typename T2, typename T3>
+      struct result { typedef void type; };
+      
+      void operator()(const expression& e, 
+                      bool& pass, 
+                      std::ostream& error_msgs) const {
+        pass = !e.expression_type().is_void();
+        if (!pass) {
+          error_msgs << "attempt to increment log prob with void expression" << std::endl;
+        }
+      }
+    };
+    boost::phoenix::function<validate_non_void_expression> validate_non_void_expression_f;
+    
 
     template <typename Iterator>
     statement_grammar<Iterator>::statement_grammar(variable_map& var_map,
@@ -447,33 +534,35 @@ namespace stan {
       using boost::spirit::qi::labels::_a;
       using boost::spirit::qi::labels::_r1;
       using boost::spirit::qi::labels::_r2;
+      using boost::spirit::qi::labels::_r3;
 
-      // _r1 true if sample_r allowed (inherited)
-      // _r2 source of variables allowed for assignments
-      // set to true if sample_r are allowed
+      // inherited features
+      //   _r1 true if sample_r allowed
+      //   _r2 source of variables allowed for assignments
+      //   _r3 true if return_r allowed 
       statement_r.name("statement");
       statement_r
         %= no_op_statement_r                        // key ";"
-        | statement_seq_r(_r1,_r2)                  // key "{"
-        | increment_log_prob_statement_r(_r2)       // key "increment"
-        | for_statement_r(_r1,_r2)                  // key "for"
-        | while_statement_r(_r1,_r2)                // key "while"
-        | statement_2_g(_r1,_r2)                    // key "if"
+        | statement_seq_r(_r1,_r2,_r3)              // key "{"
+        | increment_log_prob_statement_r(_r1,_r2)   // key "increment_log_prob"
+        | for_statement_r(_r1,_r2,_r3)              // key "for"
+        | while_statement_r(_r1,_r2,_r3)            // key "while"
+        | statement_2_g(_r1,_r2,_r3)                // key "if"
         | print_statement_r(_r2)                    // key "print"
+        | return_statement_r(_r2)               // key "return"
+        | void_return_statement_r(_r2)              // key "return"
         | assignment_r(_r2)                         // lvalue "<-"
-        // [_pass = validate_assignment_f(_1,_r2,boost::phoenix::ref(var_map_),
-        // boost::phoenix::ref(error_msgs_))]
         | sample_r(_r1,_r2)                         // expression "~"
         | expression_g(_r2)                         // expression
           [expression_as_statement_f(_pass,_1,boost::phoenix::ref(error_msgs_))]
         ;
 
-      // _r1, _r2 same as statement_r
+      // _r1, _r2, _r3 same as statement_r
       statement_seq_r.name("sequence of statements");
       statement_seq_r
         %= lit('{')
         > local_var_decls_r[_a = _1]
-        > *statement_r(_r1,_r2)
+        > *statement_r(_r1,_r2,_r3)
         > lit('}')
         > eps[unscope_locals_f(_a,boost::phoenix::ref(var_map_))]
         ;
@@ -481,15 +570,20 @@ namespace stan {
       local_var_decls_r
         %= var_decls_g(false,local_origin); // - constants
 
+      // inherited  _r1 = true if samples allowed as statements
       increment_log_prob_statement_r.name("increment log prob statement");
       increment_log_prob_statement_r
-        = lit("increment_log_prob")
+        %= lit("increment_log_prob") 
+        > eps[ validate_allow_sample_f(_r1,_pass,
+                                       boost::phoenix::ref(error_msgs_)) ]
         > lit('(')
-        > expression_g(_r1)
+        > expression_g(_r2) [ validate_non_void_expression_f(_1,_pass,
+                                                             boost::phoenix::ref(error_msgs_)) ]
         > lit(')')
         > lit(';') 
         ;
 
+      // _r1, _r2, _r3 same as statement_r
       while_statement_r.name("while statement");
       while_statement_r
         = lit("while")
@@ -498,12 +592,12 @@ namespace stan {
           [_pass = add_while_condition_f(_val,_1,
                                          boost::phoenix::ref(error_msgs_))]
         > lit(')')
-        > statement_r(_r1,_r2)
+        > statement_r(_r1,_r2,_r3)
           [add_while_body_f(_val,_1)]
         ;
       
 
-      // _r1, _r2 same as statement_r
+      // _r1, _r2, _r3 same as statement_r
       for_statement_r.name("for statement");
       for_statement_r
         %= lit("for")
@@ -515,7 +609,7 @@ namespace stan {
         > lit("in")
         > range_r(_r2)
         > lit(')')
-        > statement_r(_r1,_r2)
+        > statement_r(_r1,_r2,_r3)
         > eps 
         [remove_loop_identifier_f(_a,boost::phoenix::ref(var_map_))];
       ;
@@ -546,10 +640,10 @@ namespace stan {
       range_r.name("range expression pair, colon");
       range_r 
         %= expression_g(_r1)
-        [_pass = validate_int_expr2_f(_1,boost::phoenix::ref(error_msgs_))]
+           [validate_int_expr2_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
         >> lit(':') 
         >> expression_g(_r1)
-        [_pass = validate_int_expr2_f(_1,boost::phoenix::ref(error_msgs_))];
+           [validate_int_expr2_f(_1,_pass,boost::phoenix::ref(error_msgs_))];
 
       assignment_r.name("variable assignment by expression");
       assignment_r
@@ -574,7 +668,7 @@ namespace stan {
       dims_r 
         %= lit('[') 
         > (expression_g(_r1)
-           [_pass = validate_int_expr2_f(_1,boost::phoenix::ref(error_msgs_))]
+           [validate_int_expr2_f(_1,_pass,boost::phoenix::ref(error_msgs_))]
            % ',')
         > lit(']')
         ;
@@ -585,8 +679,8 @@ namespace stan {
         %= ( expression_g(_r2)
              >> lit('~') )
         > eps
-          [_pass = validate_allow_sample_f(_r1,
-                                           boost::phoenix::ref(error_msgs_))]
+          [validate_allow_sample_f(_r1,_pass,
+                                   boost::phoenix::ref(error_msgs_))]
         > distribution_r(_r2)
         > -truncation_range_r(_r2)
         > lit(';')
@@ -595,12 +689,14 @@ namespace stan {
                                      boost::phoenix::ref(var_map_),
                                      boost::phoenix::ref(error_msgs_))]
         ;
+
       distribution_r.name("distribution and parameters");
       distribution_r
         %= ( identifier_r
              >> lit('(')
              >> -(expression_g(_r1) % ',') )
-        > lit(')');
+        > lit(')')
+        ;
 
       truncation_range_r.name("range pair");
       truncation_range_r
@@ -609,12 +705,35 @@ namespace stan {
         > -expression_g(_r1)
         > lit(',')
         > -expression_g(_r1)
-        > lit(']');
+        > lit(']')
+        ;
+
+      // _r1 = allow sampling, _r2 = var origin
+      return_statement_r.name("return statement");
+      return_statement_r
+        %= lit("return")
+        >> expression_g(_r1)
+        >> lit(';') [ validate_return_allowed_f(_r1,_pass,
+                                                boost::phoenix::ref(error_msgs_)) ]
+        ;
+
+      // _r1 = var origin
+      void_return_statement_r.name("void return statement");
+      void_return_statement_r
+        = lit("return")[_val = expression()]
+        >> lit(';') [ validate_void_return_allowed_f(_r1,_pass,
+                                                     boost::phoenix::ref(error_msgs_)) ]
+        ;
 
       no_op_statement_r.name("no op statement");
       no_op_statement_r 
         %= lit(';') [_val = no_op_statement()];  // ok to re-use instance
 
+      using boost::spirit::qi::on_error;
+      using boost::spirit::qi::fail;
+      using boost::spirit::qi::rethrow;
+      using namespace boost::spirit::qi::labels;
+      
     }
 
   }
