@@ -27,12 +27,12 @@ namespace stan {
      */
     template <typename T>
     inline typename boost::math::tools::promote_args<T>::type
-    lmgamma(unsigned int k, T x) {
+    lmgamma(const int k, T x) {
       using boost::math::lgamma;
       typename boost::math::tools::promote_args<T>::type result 
         = k * (k - 1) * LOG_PI_OVER_FOUR;
 
-      for (unsigned int j = 1; j <= k; ++j)
+      for (int j = 1; j <= k; ++j)
         result += lgamma(x + (1.0 - j) / 2.0);
       return result;
     }
