@@ -3,7 +3,7 @@
 
 #include <boost/math/tools/promotion.hpp>
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/validate_matching_dims.hpp>
+#include <stan/math/error_handling/matrix/check_matching_dims.hpp>
 
 namespace stan {
   namespace math {
@@ -26,7 +26,8 @@ namespace stan {
     Eigen::Matrix<typename boost::math::tools::promote_args<T1,T2>::type,R,C>
     add(const Eigen::Matrix<T1,R,C>& m1,
         const Eigen::Matrix<T2,R,C>& m2) {
-      stan::math::validate_matching_dims(m1,m2,"add");
+      stan::math::check_matching_dims("add(%1%)",m1,"m1",
+                                      m2,"m2",(double*)0);
       Eigen::Matrix<typename boost::math::tools::promote_args<T1,T2>::type,R,C>      
         result(m1.rows(),m1.cols());
       for (int i = 0; i < result.size(); ++i)
