@@ -2,7 +2,7 @@
 #define __STAN__MATH__MATRIX__INVERSE_HPP__
 
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/validate_square.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
   namespace math {
@@ -16,7 +16,7 @@ namespace stan {
     inline
     Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>
     inverse(const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& m) {
-      validate_square(m,"matrix inverse");
+      stan::math::check_square("inverse(%1%)",m,"m",(double*)0);
       return m.inverse();
     }
 
