@@ -2,7 +2,7 @@
 #define __STAN__MATH__MATRIX__LOG_DETERMINANT_HPP__
 
 #include <stan/math/matrix/Eigen.hpp>
-#include <stan/math/matrix/validate_square.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 
 namespace stan {
   namespace math {
@@ -16,7 +16,7 @@ namespace stan {
      */
     template <typename T,int R, int C>
     inline T log_determinant(const Eigen::Matrix<T,R,C>& m) {
-      stan::math::validate_square(m,"log_determinant");
+      stan::math::check_square("log_determinant(%1%)",m,"m",(double*)0);
       return m.colPivHouseholderQr().logAbsDeterminant();
     }
     
