@@ -2,7 +2,7 @@
 #define __STAN__MATH__REP_ROW_VECTOR_HPP__
 
 #include <boost/math/tools/promotion.hpp>
-#include <stan/math/validate_non_negative_rep.hpp>
+#include <stan/math/error_handling/check_nonnegative.hpp>
 #include <stan/math/matrix/Eigen.hpp>
 
 namespace stan {
@@ -13,7 +13,7 @@ namespace stan {
     inline Eigen::Matrix<typename boost::math::tools::promote_args<T>::type,
                          1,Eigen::Dynamic>
     rep_row_vector(const T& x, int m) {
-      validate_non_negative_rep(m,"rep_row_vector");
+      check_nonnegative("rep_row_vector(%1%)", m,"m", (double*)0);
       return Eigen::Matrix<typename boost::math::tools::promote_args<T>::type,
                            1,Eigen::Dynamic>::Constant(m,x);
     }
