@@ -58,21 +58,22 @@ namespace stan {
       Eigen::Matrix<Eigen::MatrixXd, Eigen::Dynamic, 1> samples_;
       Eigen::VectorXi warmup_;
       
-      double mean(const Eigen::VectorXd& x) {
+      static double mean(const Eigen::VectorXd& x) {
         return (x.array() / x.size()).sum();
       }
 
-      double variance(const Eigen::VectorXd& x) {
+      static double variance(const Eigen::VectorXd& x) {
         double m = mean(x);
         return ((x.array() - m) / std::sqrt((x.size() - 1.0))).square().sum();
       }
 
-      double sd(const Eigen::VectorXd& x) {
+      static double sd(const Eigen::VectorXd& x) {
         return std::sqrt(variance(x));
       }
 
 
-      double covariance(const Eigen::VectorXd& x, const Eigen::VectorXd& y) {
+      static double covariance(const Eigen::VectorXd& x, 
+                               const Eigen::VectorXd& y) {
         if (x.rows() != y.rows())
           std::cerr << "warning: covariance of different length chains";
         using boost::accumulators::accumulator_set;
@@ -90,7 +91,8 @@ namespace stan {
         return boost::accumulators::covariance(acc) * M / (M-1);
       }
 
-      double correlation(const Eigen::VectorXd& x, const Eigen::VectorXd& y) {
+      static double correlation(const Eigen::VectorXd& x, 
+                                const Eigen::VectorXd& y) {
         if (x.rows() != y.rows())
           std::cerr << "warning: covariance of different length chains";
         using boost::accumulators::accumulator_set;
@@ -99,7 +101,8 @@ namespace stan {
         using boost::accumulators::tag::covariance;
         using boost::accumulators::tag::covariate1;
 
-        accumulator_set<double, stats<variance, covariance<double, covariate1> > > acc_xy;
+        accumulator_set<double, stats<variance, 
+                                      covariance<double, covariate1> > > acc_xy;
         accumulator_set<double, stats<variance> > acc_y;
   
         int M = std::min(x.size(), y.size());
@@ -111,10 +114,11 @@ namespace stan {
         double cov = boost::accumulators::covariance(acc_xy);
         if (cov > -1e-8 && cov < 1e-8)
           return cov;
-        return cov / std::sqrt(boost::accumulators::variance(acc_xy) * boost::accumulators::variance(acc_y));
+        return cov / std::sqrt(boost::accumulators::variance(acc_xy) 
+                               * boost::accumulators::variance(acc_y));
       }
       
-      double quantile(const Eigen::VectorXd& x, const double prob) {
+      static double quantile(const Eigen::VectorXd& x, const double prob) {
         using boost::accumulators::accumulator_set;
         using boost::accumulators::left;
         using boost::accumulators::quantile_probability;
@@ -140,7 +144,9 @@ namespace stan {
         return boost::accumulators::quantile(acc, quantile_probability=prob);
       }
 
-      Eigen::VectorXd quantiles(const Eigen::VectorXd& x, const Eigen::VectorXd& probs) {
+      static Eigen::VectorXd 
+      quantiles(const Eigen::VectorXd& x, const Eigen::VectorXd& probs)
+      {
         using boost::accumulators::accumulator_set;
         using boost::accumulators::left;
         using boost::accumulators::quantile_probability;
@@ -166,14 +172,16 @@ namespace stan {
         Eigen::VectorXd q(probs.size());  
         for (int i = 0; i < probs.size(); i++) {
           if (probs(i) < 0.5) 
-            q(i) = boost::accumulators::quantile(acc_left, quantile_probability=probs(i));
+            q(i) = boost::accumulators::quantile(acc_left, 
+                                                 quantile_probability=probs(i));
           else
-            q(i) = boost::accumulators::quantile(acc_right, quantile_probability=probs(i));
+            q(i) = boost::accumulators::quantile(acc_right, 
+                                                 quantile_probability=probs(i));
         }
         return q;
       }
 
-      Eigen::VectorXd autocorrelation(const Eigen::VectorXd& x) {
+      static Eigen::VectorXd autocorrelation(const Eigen::VectorXd& x) {
         std::vector<double> ac;
         std::vector<double> sample(x.size());
         for (int i = 0; i < x.size(); i++)
@@ -186,7 +194,7 @@ namespace stan {
         return ac2;
       }
 
-      Eigen::VectorXd autocovariance(const Eigen::VectorXd& x) {
+      static Eigen::VectorXd autocovariance(const Eigen::VectorXd& x) {
         std::vector<double> ac;
         std::vector<double> sample(x.size());
         for (int i = 0; i < x.size(); i++)
@@ -214,7 +222,8 @@ namespace stan {
        * 
        * @return 
        */
-      double effective_sample_size(const Eigen::Matrix<Eigen::VectorXd, Eigen::Dynamic, 1> &samples) {
+      double effective_sample_size(const Eigen::Matrix<Eigen::VectorXd,
+                                   Eigen::Dynamic, 1> &samples) const {
         int chains = samples.size();
   
         // need to generalize to each jagged samples per chain
@@ -274,7 +283,10 @@ namespace stan {
        * 
        * @return 
        */
-      double split_potential_scale_reduction(const Eigen::Matrix<Eigen::VectorXd, Eigen::Dynamic, 1> &samples) {
+      double 
+      split_potential_scale_reduction(
+          const Eigen::Matrix<Eigen::VectorXd, 
+                              Eigen::Dynamic, 1> &samples) const {
         int chains = samples.size();
         int n_samples = samples(0).size();
         for (int chain = 1; chain < chains; chain++) {
@@ -295,7 +307,6 @@ namespace stan {
           split_chain_var(2*chain+1) = variance(samples(chain).bottomRows(n));
         }
 
-
         double var_between = n * variance(split_chain_mean);
         double var_within = mean(split_chain_var);
       
@@ -306,6 +317,11 @@ namespace stan {
     public:
       chains(const Eigen::Matrix<std::string, Eigen::Dynamic, 1>& param_names) 
         : param_names_(param_names) { }
+
+      chains(const std::vector<std::string>& param_names) : param_names_(param_names.size()) {
+          for (size_t i = 0; i < param_names.size(); i++)
+              param_names_(i) = param_names[i];
+      }
       
       chains(const stan::io::stan_csv& stan_csv) 
         : param_names_(stan_csv.header) {
@@ -313,23 +329,23 @@ namespace stan {
           add(stan_csv);
       }
       
-      inline const int num_chains() {
+      inline int num_chains() const {
         return samples_.size();
       }
       
-      inline const int num_params() { 
+      inline int num_params() const { 
         return param_names_.size();
       }
 
-      const Eigen::Matrix<std::string, Eigen::Dynamic, 1>& param_names() {
+      const Eigen::Matrix<std::string, Eigen::Dynamic, 1>& param_names() const {
         return param_names_;
       }
 
-      const std::string& param_name(int j) {
+      const std::string& param_name(int j) const {
         return param_names_(j);
       }
 
-      const int index(const std::string& name) {
+      int index(const std::string& name) const {
         int index = -1;
         for (int i = 0; i < param_names_.size(); i++)
           if (param_names_(i) == name)
@@ -345,30 +361,30 @@ namespace stan {
         warmup_.setConstant(warmup);
       }
       
-      const Eigen::VectorXi& warmup() {
+      const Eigen::VectorXi& warmup() const {
         return warmup_;
       }
       
-      const int warmup(const int chain) {
+      int warmup(const int chain) const {
         return warmup_(chain);
       }
 
-      const int num_samples(const int chain) {
+      int num_samples(const int chain) const {
         return samples_(chain).rows();
       }
 
-      const int num_samples() {
+      int num_samples() const {
         int n = 0;
         for (int chain = 0; chain < num_chains(); chain++)
           n += num_samples(chain);
         return n;
       }
 
-      const int num_kept_samples(const int chain) {
+      int num_kept_samples(const int chain) const {
         return num_samples(chain) - warmup(chain);
       }
       
-      const int num_kept_samples() {
+      int num_kept_samples() const {
         int n = 0;
         for (int chain = 0; chain < num_chains(); chain++)
           n += num_kept_samples(chain);
@@ -378,12 +394,15 @@ namespace stan {
       void add(const int chain,
                const Eigen::MatrixXd& sample) {
         if (sample.cols() != num_params())
-          throw std::invalid_argument("add(chain,sample): number of columns in sample does not match chains");
+          throw std::invalid_argument("add(chain,sample): number of columns"
+                                      " in sample does not match chains");
         if (num_chains() == 0 || chain >= num_chains()) {
           int n = num_chains();
     
-          // Need this block for Windows. conservativeResize does not keep the references.
-          Eigen::Matrix<Eigen::MatrixXd, Eigen::Dynamic, 1> samples_copy(num_chains());
+          // Need this block for Windows. conservativeResize 
+          // does not keep the references.
+          Eigen::Matrix<Eigen::MatrixXd, Eigen::Dynamic, 1> 
+            samples_copy(num_chains());
           Eigen::VectorXi warmup_copy(num_chains());
           for (int i = 0; i < n; i++) {
             samples_copy(i) = samples_(i);
@@ -411,26 +430,48 @@ namespace stan {
         if (sample.rows() == 0)
           return;
         if (sample.cols() != num_params())
-          throw std::invalid_argument("add(sample): number of columns in sample does not match chains");
+          throw std::invalid_argument("add(sample): number of columns in"
+                                      " sample does not match chains");
         add(num_chains(), sample);
       }
 
+      void add(const std::vector<std::vector<double> >& sample) {
+        /**
+        * Convert a vector of vector<double> to Eigen::MatrixXd
+        *
+        * This method is added for the benefit of software wrapping
+        * Stan (e.g., PyStan) so that it need not additionally wrap Eigen.
+        *
+        */
+        int n_row = sample.size();
+        if (n_row == 0)
+            return;
+        int n_col = sample[0].size();
+        Eigen::MatrixXd sample_copy(n_row, n_col);
+        for (int i = 0; i < n_row; i++) {
+            sample_copy.row(i) = Eigen::VectorXd::Map(&sample[i][0], sample[0].size());
+        }
+        add(sample_copy);
+      }
+
       void add(const stan::io::stan_csv& stan_csv) {
         if (stan_csv.header.size() != num_params())
-          throw std::invalid_argument("add(stan_csv): number of columns in sample does not match chains");
+          throw std::invalid_argument("add(stan_csv): number of columns in"
+                                      " sample does not match chains");
         if (!param_names_.cwiseEqual(stan_csv.header).all()) {
-          throw std::invalid_argument("add(stan_csv): header does not match chain's header");
+          throw std::invalid_argument("add(stan_csv): header does not match"
+                                      " chain's header");
         }
         add(stan_csv.samples);
         if (stan_csv.metadata.save_warmup)
           set_warmup(num_chains()-1, stan_csv.metadata.num_warmup);
       }
       
-      Eigen::VectorXd samples(const int chain, const int index) {
+      Eigen::VectorXd samples(const int chain, const int index) const {
         return samples_(chain).col(index).bottomRows(num_kept_samples(chain));
       }
       
-      Eigen::VectorXd samples(const int index) {
+      Eigen::VectorXd samples(const int index) const {
         Eigen::VectorXd s(num_kept_samples());
         int start = 0;
         for (int chain = 0; chain < num_chains(); chain++) {
@@ -441,137 +482,149 @@ namespace stan {
         return s;
       }
 
-      Eigen::VectorXd samples(const int chain, const std::string& name) {
+      Eigen::VectorXd samples(const int chain, const std::string& name) const {
         return samples(chain,index(name));
       }
       
-      Eigen::VectorXd samples(const std::string& name) {
+      Eigen::VectorXd samples(const std::string& name) const {
         return samples(index(name));
       }
       
-      double mean(const int chain, const int index) {
+      double mean(const int chain, const int index) const {
         return mean(samples(chain,index));
       }
       
-      double mean(const int index) {
+      double mean(const int index) const {
         return mean(samples(index));
       }
 
-      double mean(const int chain, const std::string& name) {
+      double mean(const int chain, const std::string& name) const {
         return mean(chain, index(name));
       }
       
-      double mean(const std::string& name) {
+      double mean(const std::string& name) const {
         return mean(index(name));
       }
 
-      double sd(const int chain, const int index) { 
+      double sd(const int chain, const int index) const { 
         return sd(samples(chain,index));
       }
       
-      double sd(const int index) {
+      double sd(const int index) const {
         return sd(samples(index));
       }
 
-      double sd(const int chain, const std::string& name) { 
+      double sd(const int chain, const std::string& name) const { 
         return sd(chain, index(name));
       }
       
-      double sd(const std::string& name) {
+      double sd(const std::string& name) const {
         return sd(index(name));
       }
       
-      double variance(const int chain, const int index) {
+      double variance(const int chain, const int index) const {
         return variance(samples(chain,index));
       }
       
-      double variance(const int index) {   
+      double variance(const int index) const {
         return variance(samples(index));
       }
 
-      double variance(const int chain, const std::string& name) {
+      double variance(const int chain, const std::string& name) const {
         return variance(chain, index(name));
       }
       
-      double variance(const std::string& name) {   
+      double variance(const std::string& name) const {   
         return variance(index(name));
       }
 
-      double covariance(const int chain, const int index1, const int index2) {
+      double 
+      covariance(const int chain, const int index1, const int index2) const {
         return covariance(samples(chain,index1), samples(chain,index2));
       }
       
-      double covariance(const int index1, const int index2) {
+      double covariance(const int index1, const int index2) const {
         return covariance(samples(index1), samples(index2));
       }
 
-      double covariance(const int chain, const std::string& name1, const std::string& name2) {
+      double covariance(const int chain, const std::string& name1,
+                        const std::string& name2) const {
         return covariance(chain, index(name1), index(name2));
       }
       
-      double covariance(const std::string& name1, const std::string& name2) {
+      double 
+      covariance(const std::string& name1, const std::string& name2) const {
         return covariance(index(name1), index(name2));
       }
 
-      double correlation(const int chain, const int index1, const int index2) {
+      double 
+      correlation(const int chain, const int index1, const int index2) const {
         return correlation(samples(chain,index1),samples(chain,index2));
       }
       
-      double correlation(const int index1, const int index2) {
+      double correlation(const int index1, const int index2) const {
         return correlation(samples(index1),samples(index2));
       }
 
-      double correlation(const int chain, const std::string& name1, const std::string& name2) {
+      double correlation(const int chain, const std::string& name1,
+                         const std::string& name2) const {
         return correlation(chain, index(name1), index(name2));
       }
       
-      double correlation(const std::string& name1, const std::string& name2) {
+      double 
+      correlation(const std::string& name1, const std::string& name2) const {
         return correlation(index(name1), index(name2));
       }
 
-      double quantile(const int chain, const int index, const double prob) {
+      double 
+      quantile(const int chain, const int index, const double prob) const {
         return quantile(samples(chain,index), prob);
       }
       
-      double quantile(const int index, const double prob) {
+      double quantile(const int index, const double prob) const {
         return quantile(samples(index), prob);
       }
 
-      double quantile(const int chain, const std::string& name, const double prob) {
+      double quantile(int chain, const std::string& name, double prob) const {
         return quantile(chain, index(name), prob);
       }
       
-      double quantile(const std::string& name, const double prob) {
+      double quantile(const std::string& name, const double prob) const {
         return quantile(index(name), prob);
       }
 
-      Eigen::VectorXd quantiles(const int chain, const int index, const Eigen::VectorXd& probs) {
+      Eigen::VectorXd
+      quantiles(int chain, int index, const Eigen::VectorXd& probs) const {
         return quantiles(samples(chain,index), probs);
       }
 
-      Eigen::VectorXd quantiles(const int index, const Eigen::VectorXd& probs) {
+      Eigen::VectorXd quantiles(int index, const Eigen::VectorXd& probs) const {
         return quantiles(samples(index), probs);
       }
 
-      Eigen::VectorXd quantiles(const int chain, 
-                                const std::string& name, const Eigen::VectorXd& probs) {
+      Eigen::VectorXd
+      quantiles(int chain, const std::string& name, 
+                const Eigen::VectorXd& probs) const {
         return quantiles(chain, index(name), probs);
       }
 
-      Eigen::VectorXd quantiles(const std::string& name, const Eigen::VectorXd& probs) {
+      Eigen::VectorXd 
+      quantiles(const std::string& name, const Eigen::VectorXd& probs) const {
         return quantiles(index(name), probs);
       }
       
-      Eigen::Vector2d central_interval(const int chain, const int index, const double prob) {
+      Eigen::Vector2d central_interval(int chain, int index, 
+                                       double prob) const {
         double low_prob = (1-prob)/2;
         double high_prob = 1-low_prob;
   
         Eigen::Vector2d interval;
-        interval << quantile(chain,index,low_prob), quantile(chain,index,high_prob);
+        interval 
+          << quantile(chain,index,low_prob), quantile(chain,index,high_prob);
         return interval;
       }
 
-      Eigen::Vector2d central_interval(const int index, const double prob) {
+      Eigen::Vector2d central_interval(int index, double prob) const {
         double low_prob = (1-prob)/2;
         double high_prob = 1-low_prob;
   
@@ -580,53 +633,59 @@ namespace stan {
         return interval;
       }
 
-      Eigen::Vector2d central_interval(const int chain, 
-                                       const std::string& name, const double prob) {
+      Eigen::Vector2d
+      central_interval(int chain, const std::string& name, 
+                       double prob) const {
         return central_interval(chain, index(name), prob);
       }
 
-      Eigen::Vector2d central_interval(const std::string& name, const double prob) {
+      Eigen::Vector2d central_interval(const std::string& name, 
+                                       double prob) const {
         return central_interval(index(name), prob);
       }
 
-      Eigen::VectorXd autocorrelation(const int chain, const int index) {
+      Eigen::VectorXd autocorrelation(const int chain, const int index) const {
         return autocorrelation(samples(chain, index));
       }
 
-      Eigen::VectorXd autocorrelation(const int chain, const std::string& name) {
+      Eigen::VectorXd autocorrelation(int chain, 
+                                      const std::string& name) const {
         return autocorrelation(chain, index(name));
       }
       
-      Eigen::VectorXd autocovariance(const int chain, const int index) {
+      Eigen::VectorXd autocovariance(const int chain, const int index) const {
         return autocovariance(samples(chain,index));
       }
 
-      Eigen::VectorXd autocovariance(const int chain, const std::string& name) {
+      Eigen::VectorXd autocovariance(int chain, const std::string& name) const {
         return autocovariance(chain, index(name));
       }
 
       // FIXME: reimplement using autocorrelation.
-      double effective_sample_size(const int index) {
-        Eigen::Matrix<Eigen::VectorXd, Eigen::Dynamic, 1> samples(num_chains());
+      double effective_sample_size(const int index) const {
+        Eigen::Matrix<Eigen::VectorXd, Eigen::Dynamic, 1> 
+          samples(num_chains());
         for (int chain = 0; chain < num_chains(); chain++) {
           samples(chain) = this->samples(chain, index);
         }
         return effective_sample_size(samples);
       }
 
-      double effective_sample_size(const std::string& name) {
+      double effective_sample_size(const std::string& name) const {
         return effective_sample_size(index(name));
       }
       
-      double split_potential_scale_reduction(const int index) {  
-        Eigen::Matrix<Eigen::VectorXd, Eigen::Dynamic, 1> samples(num_chains());
+      double split_potential_scale_reduction(const int index) const 
+      {
+        Eigen::Matrix<Eigen::VectorXd, Eigen::Dynamic, 1> 
+          samples(num_chains());
         for (int chain = 0; chain < num_chains(); chain++) {
           samples(chain) = this->samples(chain, index);
         }
         return split_potential_scale_reduction(samples);
       }
       
-      double split_potential_scale_reduction(const std::string& name) {  
+      double split_potential_scale_reduction(const std::string& name) const {  
         return split_potential_scale_reduction(index(name));
       }
     };
