@@ -19,10 +19,10 @@ namespace stan {
       
     public:
       
-        adapt_dense_e_static_hmc(M &m, BaseRNG& rng, int max_adapt,
+        adapt_dense_e_static_hmc(M &m, BaseRNG& rng,
                                  std::ostream* o = &std::cout, std::ostream* e = 0):
         dense_e_static_hmc<M, BaseRNG>(m, rng, o, e),
-        stepsize_covar_adapter(m.num_params_r(), max_adapt)
+        stepsize_covar_adapter(m.num_params_r())
       {};
       
       ~adapt_dense_e_static_hmc() {};
