@@ -11,11 +11,11 @@
 #include <boost/math/tools/promotion.hpp>
 #include <stan/agrad/rev/matrix.hpp>
 #include <stan/math.hpp>
+#include <stan/math/error_handling.hpp>
+#include <stan/math/error_handling/matrix/check_square.hpp>
 #include <stan/math/matrix.hpp>
 #include <stan/math/matrix/sum.hpp>
-#include <stan/math/error_handling.hpp>
 #include <stan/math/matrix_error_handling.hpp>
-
 #include <stan/math/matrix/multiply_lower_tri_self_transpose.hpp>
 
 namespace stan {
@@ -25,6 +25,45 @@ namespace stan {
 
     const double CONSTRAINT_TOLERANCE = 1E-8;
 
+    /**
+     * This function is intended to make starting values, given a unit
+     * upper-triangular matrix U such that U'DU is a correlation matrix
+     *   
+     * @param CPCs fill this unbounded
+     * @param Sigma U matrix
+     */
+    template<typename T>
+    void    
+    factor_U(const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& U,
+             Eigen::Array<T,Eigen::Dynamic,1>& CPCs) { 
+
+      size_t K = U.rows();
+      size_t position = 0;
+      size_t pull = K - 1;
+
+      if (K == 2) {
+        CPCs(0) = atanh(U(0,1));
+        return;
+      }
+
+      Eigen::Array<T,1,Eigen::Dynamic> temp = U.row(0).tail(pull);
+
+      CPCs.head(pull) = temp;
+
+      Eigen::Array<T,Eigen::Dynamic,1> acc(K);
+      acc(0) = -0.0;
+      acc.tail(pull) = 1.0 - temp.square();
+      for(size_t i = 1; i < (K - 1); i++) {
+        position += pull;
+        pull--;
+        temp = U.row(i).tail(pull);
+        temp /= sqrt(acc.tail(pull) / acc(i));
+        CPCs.segment(position, pull) = temp;
+        acc.tail(pull) *= 1.0 - temp.square();
+      }
+      CPCs = 0.5 * ( (1.0 + CPCs) / (1.0 - CPCs) ).log(); // now unbounded
+    }
+    
 
     /**
      * This function is intended to make starting values, given a
@@ -33,16 +72,16 @@ namespace stan {
      * The transformations are hard coded as log for standard
      * deviations and Fisher transformations (atanh()) of CPCs
      *
-     * @param CPCs fill this unbounded
-     * @param sds fill this unbounded
-     * @param Sigma covariance matrix
+     * @param[in] Sigma covariance matrix
+     * @param[out] CPCs fill this unbounded (does not resize)
+     * @param[out] sds fill this unbounded (does not resize)
      * @return false if any of the diagonals of Sigma are 0
      */
     template<typename T>
     bool
-    factor_cov_matrix(Eigen::Array<T,Eigen::Dynamic,1>& CPCs,
-              Eigen::Array<T,Eigen::Dynamic,1>& sds, 
-              const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& Sigma) {
+    factor_cov_matrix(const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& Sigma,
+                      Eigen::Array<T,Eigen::Dynamic,1>& CPCs,
+                      Eigen::Array<T,Eigen::Dynamic,1>& sds) {
 
       size_t K = sds.rows();
 
@@ -62,26 +101,7 @@ namespace stan {
       if (!ldlt.isPositive()) 
         return false;
       Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic> U = ldlt.matrixU();
-
-      size_t position = 0;
-      size_t pull = K - 1;
-
-      Eigen::Array<T,1,Eigen::Dynamic> temp = U.row(0).tail(pull);
-
-      CPCs.head(pull) = temp;
-
-      Eigen::Array<T,Eigen::Dynamic,1> acc(K);
-      acc(0) = -0.0;
-      acc.tail(pull) = 1.0 - temp.square();
-      for(size_t i = 1; i < (K - 1); i++) {
-        position += pull;
-        pull--;
-        temp = U.row(i).tail(pull);
-        temp /= sqrt(acc.tail(pull) / acc(i));
-        CPCs.segment(position, pull) = temp;
-        acc.tail(pull) *= 1.0 - temp.square();
-      }
-      CPCs = 0.5 * ( (1.0 + CPCs) / (1.0 - CPCs) ).log(); // now unbounded
+      factor_U(U, CPCs);
       return true;
     }
 
@@ -1145,7 +1165,7 @@ namespace stan {
         stick_len += x(k);
         T z_k(x(k) / stick_len);
         y(k) = logit(z_k) + log(Km1 - k); 
-        // log(Km-k) = logit(1.0 / (Km1 + 1 - k));
+        // note: log(Km1 - k) = logit(1.0 / (Km1 + 1 - k));
       }
       return y;
     }
@@ -1423,7 +1443,116 @@ namespace stan {
       return x;
     }
 
+    // CHOLESKY CORRELATION MATRIX
+
+    template <typename T>
+    Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>
+    cholesky_corr_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& y,
+                            int K) {
+      using std::sqrt;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::square;
+      int k_choose_2 = (K * (K - 1)) / 2;
+      if (k_choose_2 != y.size()) {
+        std::cout << "k_choose_2 = " << k_choose_2 << " y.size()=" << y.size() << std::endl;
+        throw std::domain_error("y is not a valid unconstrained cholesky correlation matrix."
+                                "Require (K choose 2) elements in y.");
+      }
+      Matrix<T,Dynamic,1> z(k_choose_2);
+      for (int i = 0; i < k_choose_2; ++i)
+        z(i) = corr_constrain(y(i));
+      Matrix<T,Dynamic,Dynamic> x(K,K);
+      if (K == 0) return x;
+      T zero(0);
+      for (int j = 1; j < K; ++j)
+        for (int i = 0; i < j; ++i)
+          x(i,j) = zero;
+      x(0,0) = 1;
+      int k = 0;
+      for (int i = 1; i < K; ++i) {
+        x(i,0) = z(k++);
+        T sum_sqs(square(x(i,0)));
+        for (int j = 1; j < i; ++j) {
+          x(i,j) = z(k++) * sqrt(1.0 - sum_sqs);
+          sum_sqs += square(x(i,j));
+        }
+        x(i,i) = sqrt(1.0 - sum_sqs);
+      }
+      return x;
+    }
+
+    // FIXME to match above after debugged
+    template <typename T>
+    Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>
+    cholesky_corr_constrain(const Eigen::Matrix<T,Eigen::Dynamic,1>& y,
+                            int K,
+                            T& lp) {
+      using std::sqrt;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::log1m;
+      using stan::math::square;
+      int k_choose_2 = (K * (K - 1)) / 2;
+      if (k_choose_2 != y.size()) {
+        std::cout << "k_choose_2 = " << k_choose_2 << " y.size()=" << y.size() << std::endl;
+        throw std::domain_error("y is not a valid unconstrained cholesky correlation matrix."
+                                " Require (K choose 2) elements in y.");
+      }
+      Matrix<T,Dynamic,1> z(k_choose_2);
+      for (int i = 0; i < k_choose_2; ++i)
+        z(i) = corr_constrain(y(i),lp);
+      Matrix<T,Dynamic,Dynamic> x(K,K);
+      if (K == 0) return x;
+      T zero(0);
+      for (int j = 1; j < K; ++j)
+        for (int i = 0; i < j; ++i)
+          x(i,j) = zero;
+      x(0,0) = 1;
+      int k = 0;
+      for (int i = 1; i < K; ++i) {
+        x(i,0) = z(k++);
+        T sum_sqs = square(x(i,0));
+        for (int j = 1; j < i; ++j) {
+          lp += 0.5 * log1m(sum_sqs);
+          x(i,j) = z(k++) * sqrt(1.0 - sum_sqs);
+          sum_sqs += square(x(i,j));
+        }
+        x(i,i) = sqrt(1.0 - sum_sqs);
+      }
+      return x;
+    }
+
+    
+
+    template <typename T>
+    Eigen::Matrix<T,Eigen::Dynamic,1>
+    cholesky_corr_free(const Eigen::Matrix<T,Eigen::Dynamic,Eigen::Dynamic>& x) {
+      using std::sqrt;
+      using Eigen::Matrix;
+      using Eigen::Dynamic;
+      using stan::math::square;
+
+      double bad_result; // won't be used
+      stan::math::check_square("cholesky_corr_free",x,"x",&bad_result);
+      // should validate lower-triangular, unit lengths
+
+      int K = (x.rows() * (x.rows() - 1)) / 2;
+      Matrix<T,Dynamic,1> z(K);
+      int k = 0;
+      for (int i = 1; i < x.rows(); ++i) {
+        z(k++) = corr_free(x(i,0));
+        double sum_sqs = square(x(i,0));
+        for (int j = 1; j < i; ++j) {
+          z(k++) = corr_free(x(i,j) / sqrt(1.0 - sum_sqs));
+          sum_sqs += square(x(i,j));
+        }
+      }
+      return z;
+    }
+
     // CORRELATION MATRIX
+
     /**
      * Return the correlation matrix of the specified dimensionality
      * derived from the specified vector of unconstrained values.  The
@@ -1529,7 +1658,7 @@ namespace stan {
       size_type k_choose_2 = (k * (k-1)) / 2;
       Eigen::Array<T,Eigen::Dynamic,1> x(k_choose_2);
       Eigen::Array<T,Eigen::Dynamic,1> sds(k);
-      bool successful = factor_cov_matrix(x,sds,y);
+      bool successful = factor_cov_matrix(y,x,sds);
       if (!successful)
         throw std::runtime_error("factor_cov_matrix failed on y");
       for (size_type i = 0; i < k; ++i) {
@@ -1576,8 +1705,8 @@ namespace stan {
         for (size_type n = m + 1; n < K; ++n) 
           L(m,n) = 0.0;
       }
-      // FIXME: return multiply_self_transpose
-      return L * L.transpose();
+      using stan::math::multiply_lower_tri_self_transpose;
+      return multiply_lower_tri_self_transpose(L); 
     }
 
     
@@ -1775,7 +1904,7 @@ namespace stan {
       size_type k_choose_2 = (k * (k-1)) / 2;
       Eigen::Array<T,Eigen::Dynamic,1> cpcs(k_choose_2);
       Eigen::Array<T,Eigen::Dynamic,1> sds(k);
-      bool successful = factor_cov_matrix(cpcs,sds,y);
+      bool successful = factor_cov_matrix(y,cpcs,sds);
       if (!successful)
         throw std::runtime_error ("factor_cov_matrix failed on y");
       Eigen::Matrix<T,Eigen::Dynamic,1> x(k_choose_2 + k);
