@@ -35,7 +35,10 @@
 
 
 #include "py_var_context.hpp"
-void Py_CheckUserInterrupt(void);
+#include "Python.h"
+#ifndef Py_PYTHON_H
+    #error Python headers needed to compile C extensions, please install development version of Python.
+#endif
 
 // REF: stan/common/command.hpp
 
@@ -49,10 +52,6 @@ void Py_CheckUserInterrupt(void);
 typedef std::map<std::string, std::pair<std::vector<double>, std::vector<size_t> > > vars_r_t;
 typedef std::map<std::string, std::pair<std::vector<int>, std::vector<size_t> > > vars_i_t;
 
-void Py_CheckUserInterrupt(void) {
-    // TODO(abr): currently a noop; need to check PyErr_Occured()
-}
-
 namespace pystan {
 
   enum sampling_algo_t { NUTS = 1, HMC = 2, Metropolis = 3, Fixed_param = 4};
@@ -62,12 +61,12 @@ namespace pystan {
 
   /* Simple class to store arguments provided by Python. Mirrors RStan's stan_args.
    *
-   * Apart from the PyStanArgs class all the functionality found in RStan's
+   * Apart from the StanArgs class all the functionality found in RStan's
    * stan_args.hpp such as validate_args() and the constructor is handled in
    * Python for easier debugging.
    *
    */
-  class PyStanArgs {
+  class StanArgs {
   public:
     unsigned int random_seed;
     unsigned int chain_id;
@@ -272,7 +271,7 @@ namespace pystan {
   };
 
   /* simple class to store data for Python */
-  class PyStanHolder {
+  class StanHolder {
 
       public:
           int num_failed;
@@ -282,7 +281,7 @@ namespace pystan {
           double value;
           std::vector<std::vector<double> > chains;
           std::vector<std::string> chain_names;
-          PyStanArgs args;
+          StanArgs args;
           std::vector<double> mean_pars;
           double mean_lp__;
           std::string adaptation_info;
@@ -612,7 +611,7 @@ namespace pystan {
     }
 
     template<class Sampler>
-    void init_static_hmc(stan::mcmc::base_mcmc* sampler_ptr, const PyStanArgs& args) {
+    void init_static_hmc(stan::mcmc::base_mcmc* sampler_ptr, const StanArgs& args) {
       double epsilon = args.get_ctrl_sampling_stepsize();
       double epsilon_jitter = args.get_ctrl_sampling_stepsize_jitter();
       double int_time = args.get_ctrl_sampling_int_time();
@@ -623,7 +622,7 @@ namespace pystan {
     }
 
     template<class Sampler>
-    void init_nuts(stan::mcmc::base_mcmc* sampler_ptr, const PyStanArgs& args) {
+    void init_nuts(stan::mcmc::base_mcmc* sampler_ptr, const StanArgs& args) {
       double epsilon = args.get_ctrl_sampling_stepsize();
       double epsilon_jitter = args.get_ctrl_sampling_stepsize_jitter();
       int max_depth = args.get_ctrl_sampling_max_treedepth();
@@ -635,7 +634,7 @@ namespace pystan {
     }
 
     template<class Sampler>
-    void init_adapt(stan::mcmc::base_mcmc* sampler_ptr, const PyStanArgs& args,
+    void init_adapt(stan::mcmc::base_mcmc* sampler_ptr, const StanArgs& args,
                     const Eigen::VectorXd& cont_params) {
 
       if (!args.get_ctrl_sampling_adapt_engaged()) return;
@@ -658,7 +657,7 @@ namespace pystan {
     }
 
     template<class Sampler>
-    bool init_windowed_adapt(stan::mcmc::base_mcmc* sampler_ptr, const PyStanArgs& args,
+    bool init_windowed_adapt(stan::mcmc::base_mcmc* sampler_ptr, const StanArgs& args,
                              const Eigen::VectorXd& cont_params) {
 
       init_adapt<Sampler>(sampler_ptr, args, cont_params);
@@ -670,9 +669,10 @@ namespace pystan {
       return true;
     }
 
-    struct Py_CheckUserInterrupt_Functor {
+    struct PyErr_CheckSignals_Functor {
       void operator()() {
-        Py_CheckUserInterrupt();
+        // PyErr_CheckSignals is defined in Python.h
+        PyErr_CheckSignals();
       }
     };
 
@@ -706,7 +706,7 @@ namespace pystan {
     }
 
     template <class Model, class RNG_t>
-    void execute_sampling(PyStanArgs& args, Model& model, PyStanHolder& holder,
+    void execute_sampling(StanArgs& args, Model& model, StanHolder& holder,
                           stan::mcmc::base_mcmc* sampler_ptr,
                           stan::mcmc::sample& s,
                           const std::vector<size_t>& qoi_idx,
@@ -753,12 +753,14 @@ namespace pystan {
       // Warm-Up
       clock_t start = clock();
 
-      std::string prefix = "\n";
-      std::string suffix = "";
-      Py_CheckUserInterrupt_Functor interruptCallback;
+      std::string prefix = "";
+      std::stringstream ss;
+      ss << " (Chain " << args.get_chain_id() << ")" << std::endl;
+      std::string suffix = ss.str();
+      PyErr_CheckSignals_Functor interruptCallback;
 
       stan::common::warmup<Model, RNG_t,
-                           Py_CheckUserInterrupt_Functor>
+                           PyErr_CheckSignals_Functor>
         (sampler_ptr, args.get_ctrl_sampling_warmup(), args.get_iter() - args.get_ctrl_sampling_warmup(),
          args.get_ctrl_sampling_thin(),
          args.get_ctrl_sampling_refresh(), args.get_ctrl_sampling_save_warmup(),
@@ -785,7 +787,7 @@ namespace pystan {
       start = clock();
 
       stan::common::sample<Model, RNG_t,
-                           Py_CheckUserInterrupt_Functor>
+                           PyErr_CheckSignals_Functor>
         (sampler_ptr, args.get_ctrl_sampling_warmup(), args.get_iter() - args.get_ctrl_sampling_warmup(),
          args.get_ctrl_sampling_thin(),
          args.get_ctrl_sampling_refresh(), true,
@@ -855,7 +857,7 @@ namespace pystan {
      * @param base_rng: the boost RNG instance.
      */
     template <class Model, class RNG_t>
-    int sampler_command(PyStanArgs& args, Model& model, PyStanHolder& holder,
+    int sampler_command(StanArgs& args, Model& model, StanHolder& holder,
                         const std::vector<size_t>& qoi_idx,
                         const std::vector<std::string>& fnames_oi, RNG_t& base_rng) {
 
@@ -1139,7 +1141,7 @@ namespace pystan {
           std::cout << "initial log joint probability = " << lp << std::endl;
           int m = 0;
           while ((lp - lastlp) / fabs(lp) > 1e-8) {
-            Py_CheckUserInterrupt();
+            PyErr_CheckSignals();
             lastlp = lp;
             lp = stan::optimization::newton_step(model, cont_vector, disc_vector);
             if (args.get_ctrl_optim_refresh() > 0) {
@@ -1564,7 +1566,7 @@ namespace pystan {
       return n;
     }
 
-    int call_sampler(PyStanArgs& args, PyStanHolder& holder) {
+    int call_sampler(StanArgs& args, StanHolder& holder) {
       int ret;
       ret = sampler_command(args, model_, holder, names_oi_tidx_,
                             fnames_oi_, base_rng);
